function Pulse = RaisedCos(fsT )
% RaisedCos - raised cosine pulse
%
% Generate a raised cosine pulse spanning one symbol period with fsT samples
% per symbol period. The amplitude of the pulse is normalized so that the
% pulse has energy T.
%
%          p(t) = sqrt(2/3) * (1-cos(2*pi*t/T))
% 
% Inputs:
%   fsT - number of samples 
%
% Example:
%   Pulse = RaisedCos( fsT )

% time interval from 0 to (nearly) T
tt = ( 0 : fsT-1 ) / fsT;

Pulse = sqrt(2/3) * ( 1 - cos(2*pi*tt) );
